#
# spec file for package apr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         aprver 1
%define         libname lib%{name}%{aprver}-0
%define         installbuilddir %{_libdir}/apr-%{aprver}/build
%define         includedir %{_includedir}/apr-%{aprver}
Name:           apr
Version:        1.7.5
Release:        1.4
Summary:        Apache Portable Runtime (APR) Library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://apr.apache.org/
Source0:        https://www.apache.org/dist/apr/apr-%{version}.tar.bz2
Source1:        https://www.apache.org/dist/apr/apr-%{version}.tar.bz2.asc
Source2:        https://downloads.apache.org/apr/KEYS#/%{name}.keyring
Patch5:         apr-visibility.patch
Patch9:         apr-proc-mutex-map-anon.patch
# prevent random failures of the testsuite (sendfile test)
Patch10:        apr-test-sendfile-timeout.patch
Patch11:        reproducible.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libuuid-devel
BuildRequires:  lksctp-tools-devel
# for the testsuite
BuildRequires:  netcfg libnss_usrfiles2
BuildRequires:  pkgconfig

%description
APR is Apache's Portable Runtime Library, designed to be a support
library that provides a predictable and consistent interface to
underlying platform-specific implementations.

%package -n %{libname}
Summary:        Apache Portable Runtime (APR) Library
Group:          System/Libraries

%description -n %{libname}
APR is Apache's Portable Runtime Library, designed to be a support
library that provides a predictable and consistent interface to
underlying platform-specific implementations.

The range of platform-spanning functionality provided by APR
includes: Memory allocation and memory pool functionality, atomic
operations, dynamic library handling, file I/O, command-argument
parsing, locking, hash tables and arrays, mmap functionality, network
sockets and protocols, threads, process and mutex functionality,
shared memory functionality, time routines, as well as user and group
ID services.

%package devel
Summary:        Development files for the Apache Portable Runtime (APR) library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libapr1-devel = %{version}
Obsoletes:      libapr1-devel < %{version}-%{release}

%description devel
APR is Apache's Portable Runtime Library, designed to be a support
library that provides a predictable and consistent interface to
underlying platform-specific implementations.

This subpackage contains header files for developing applications
that want to make use of APR.

%prep
%autosetup -p1

# Do not put date to doxy content
sed -i \
	-e '4 iHTML_TIMESTAMP=NO' \
	docs/doxygen.conf

%build
%configure \
	--enable-other-child \
	--with-installbuilddir=%{installbuilddir} \
	--includedir=%{includedir} \
	--with-devrandom=/dev/urandom \
	--disable-static \
	--enable-posix-shm \
	--with-sendfile
%make_build CFLAGS="%{optflags} -DREADDIR_IS_THREAD_SAFE -fvisibility=hidden -fPIC"
%make_build dox

%install
%make_install
# Move docs to more convenient location
mv docs/dox/html html
# Unpackaged files:
rm -f %{buildroot}/%{_libdir}/apr.exp
rm -f %{buildroot}%{_libdir}/libapr-%{aprver}.la

# Trim exported dependecies
sed -ri '/^LIBS=/{s,-l(uuid|crypt) ,,g;s/  */ /g}' \
      %{buildroot}%{_bindir}/apr-%{aprver}-config
sed -ri '/^Libs/{s,-l(uuid|crypt) ,,g}' \
      %{buildroot}%{_libdir}/pkgconfig/apr-%{aprver}.pc

%fdupes %{buildroot}

%check
%if ! 0%{?qemu_user_space_build}
%ifarch ppc ppc64 ppc64le
%make_build check -j1 || { echo "ignore PowerPC transient test failures"; exit 0; }
%else
%make_build check -j1
%endif
%endif

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc CHANGES
%if 0%{?suse_version} > 1315
%license LICENSE
%else
%license LICENSE
%endif
%doc NOTICE
%{_libdir}/libapr-%{aprver}.so.*
# Do NOT move to devel as this is utilized by Tomcat
%{_libdir}/libapr-%{aprver}.so

%files devel
%doc docs/APRDesign.html
%doc docs/canonical_filenames.html
%doc docs/incomplete_types
%doc docs/non_apr_programs
%doc html
%doc emacs-mode
%{includedir}
%{_bindir}/apr-%{aprver}-config
%{_libdir}/pkgconfig/apr-%{aprver}.pc
%{_libdir}/apr-%{aprver}

%changelog
* Tue Sep 17 2024 pgajdos@suse.com
- version update to 1.7.5 [bsc#1229783] CVE-2023-49582
  * ) Unix: Implement apr_shm_perms_set() for the "POSIX shm_open()"
    and "classic mmap" shared memory implementations.  [Joe Orton,
    Ruediger Pluem]
  * ) Fix missing ';' for XML/HTML hex entities from apr_escape_entity().
    [Yann Ylavic]
  * ) Fix crash in apr_pool_create() with --enable-pool-debug=all|owner.
    [Yann Ylavic]
  * ) Improve platform detection by updating config.guess and config.sub.
    [Rainer Jung]
  * ) CMake: Add support for CMAKE_WARNING_AS_ERROR. [Ivan Zhakov]
  * ) CMake: Enable support for MSVC runtime library selection by abstraction.
    [Ivan Zhakov]
  * ) CMake: Export installed targets (libapr-1, apr-1, libaprapp-1, aprapp-1)
    to apr:: namespace. [Ivan Zhakov]
- modified patches
  %% apr-visibility.patch (refreshed)
  %% reproducible.patch (refreshed)
* Mon Dec 18 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to drop build host name (boo#1084909)
* Thu Apr 20 2023 pgajdos@suse.com
- version update to 1.7.4
  * ) Fix a regression where writing to a file opened with both APR_FOPEN_APPEND
    and APR_FOPEN_BUFFERED did not properly append the data on Windows.
    (This regression was introduced in APR 1.7.3)  [Evgeny Kotkov]
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.3:
  * apr-1-config: Fix crosscompiling detection
  * configure: Add --enable-sysv-shm to use SysV shared
    memory (shmget) if available.
  * apr_socket_sendfile: Use WSAIoctl() to get TransmitFile
    function pointer on Windows. [Ivan Zhakov]
  * apr_dir_read: Do not request short file names on Windows
    7 and later. [Ivan Zhakov]
  * apr_file_gets: Optimize for buffered files on Windows.
  * Fix a deadlock when writing to locked files opened with
    APR_FOPEN_APPEND on Windows. PR 50058. [Evgeny Kotkov]
  * Don't seek to the end when opening files with
    APR_FOPEN_APPEND on Windows.
  * apr_file_write: Optimize large writes to buffered files
    on Windows.
  * apr_file_write: Optimize large reads from buffered files
    on Windows.
* Thu Feb  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.7.2:
  * CVE-2022-24963: Integer Overflow or Wraparound vulnerability in
    apr_encode functions allows an attacker to write beyond bounds
    of a buffer (boo#1207870)
  * Add error handling for lseek() failures in apr_file_write() and
    apr_file_writev()
  * Avoid an overflow on 32 bit platforms
  * Don't silently set APR_FOPEN_NOCLEANUP for apr_file_mktemp()
    created file to avoid a fd and inode leak when/if later passed
    to apr_file_setaside().
  * build system fixes and fixes for other platforms
- drop apr-CVE-2021-35940.patch included upstream (CVE-2021-35940)
* Sat Mar 26 2022 Stephan Kulow <coolo@suse.com>
- Remove autoreconf call, it breaks with uptodate autoconf versions
* Tue Feb 22 2022 pgajdos@suse.com
- deleted patches
  - apr-CVE-2021-3594.patch (renamed)
- added patches
  + apr-CVE-2021-35940.patch (correct name)
* Tue Oct 19 2021 pgajdos@suse.com
- fix shlib-policy-name-error [bsc#1191747]
* Thu Sep  2 2021 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-35940 [bsc#1190072], Regression of fix in apr 1.7
  + apr-CVE-2021-35940.patch
* Sat Aug  3 2019 Manu Maier <mmanu84@outlook.de>
- Version 1.7.0
  * apr_dir_read: [Unix] Dropped the preference of the dirread_r() flavor
    for dirread(), because the former is both deprecated and unneeded.
    [Yann Ylavic, William Rowe]
  * apr_file_info: [Win32 only] Treat only "name surrogate" reparse points
    as symlinks, and not other reparse tag types. PR47630
    [Oleg Liatte <olegliatte gmail.com>]
  * Test %%ld vs. %%lld to avoid compiler emits using APR_OFF_T_FMT, in the
    case of apparently equivilant long and long long types. [William Rowe]
  * Recognize APPLE predefined macros as equivilant to DARWIN. [Jim Jagielski]
  * Signals: Allow handling of SIGUSR2 in apr_signal_thread. [Yann Ylavic]
  * Atomics: Support for 64bit ints. [Jim Jagielski]
  * Add the apr_encode_* API that implements RFC4648 and RFC7515
    compliant BASE64, BASE64URL, BASE32, BASE32HEX and BASE16
    encode/decode functions. [Graham Leggett]
  * rand: Use arc4random_buf() on BSD platforms and getrandom() on Linux,
    when available. [Christian Weisgerber <naddy openbsd.org, Yann Ylavic]
  * Add apr_sockaddr_zone_set, apr_sockaddr_zone_set to set and retrieve
    the zone for link-local IPv6 addresses.  [Joe Orton]
  * apr_sockaddr_equal: Compare link-local IPv6 addresses with different
    zones as not equal.  [Joe Orton]
  * apr_sockaddr_ip_getbuf, apr_sockaddr_ip_get: Append "%%zone" for
    IPv6 link-local addresses.  [Joe Orton]
  * Locks: add a --disable-timedlocks config option in case users
    encounter more platforms where it fails [Nick Kew].
  * apr_allocator, apr_pools: Add apr_allocator_page_size() and
    apr_allocator_min_order_set() to respectively get the (system's) page size
    in use and set the minimum allocation size for an allocator (expressed in
    2^order pages).  [Yann Ylavic]
  * locks: provide portable implementations of timedlock()s for
    posix-sems, sysv-sems and pthreads for those platforms that
    lack native versions (eg: OSX/macOS). [Jim Jagielski]
  * locks: Introduce apr_{thread,proc,global}_mutex_timedlock().
    [Yann Ylavic]
- Remove patch
  * apr-use-getrandom.patch no longer needed, apr 1.7.0 use getrandom() on Linux,
    when available.
- Refresh apr-visibility.patch
* Fri Feb  8 2019 Petr Gajdos <pgajdos@suse.com>
- increase timeout to fix random failure of testsuite
  + apr-test-sendfile-timeout.patch
- fix build for SLE11 again
* Thu Feb  7 2019 Petr Gajdos <pgajdos@suse.com>
- linux version is now checked correctly, drop
  - apr-1.4.5-linux3.patch
    (see change log from Sun Aug  7 01:21:44 UTC 2011)
* Wed Jan 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update keyring to match current release maintainer
* Thu Oct 18 2018 Manu Maier <mmanu84@outlook.de>
- Version 1.6.5
  * Fix Win32 build breakage in apr_os_exp_time_put() in 1.6.4. [Rainer Jung]
- Version 1.6.4
  * configure: Fix detection of <net/if.h> on OpenBSD.
  PR 61976. [David Carlier <devnexen gmail.com>, Yann Ylavic]
  * Fix apr_parse_addr_port() regression in scope_id parsing introduced
  in 1.6.3.  [Rainer Jung]
  * Fix Win32 file buffer locking behavior for single threaded file streams.
  [Evgeny Kotkov, Mladen Turk, Jean-Frederic Clere]
  * Numerous corrections to APR poll behavior. [Yann Ylavic]
- Drop patch gcc8-integer-overflow.patch merged upstream
* Thu May 10 2018 matwey.kornilov@gmail.com
- Version 1.6.3:
  * apr_file_trunc: Truncating a buffered file could add unexpected
  data after the truncate position. PR 51017.
  * apr_file_trunc: Fix an issue where reading from a buffered file
  after truncate could return stale data from the buffer.
  * apr_ipsubnet_create() now fails for an empty input string.
- fixes [bsc#1092981]
* Wed Apr 18 2018 mliska@suse.cz
- Add gcc8-integer-overflow.patch to handle an undefined
  behavior (boo#1090085).
* Tue Jan 23 2018 normand@linux.vnet.ibm.com
- ignore PowerPC transient test failures
* Tue Nov  7 2017 mpluskal@suse.com
- Do not require python for building - its not needed anyways
  (fate#323526)
* Mon Oct 16 2017 mpluskal@suse.com
- We need to obsolete same version of package (bsc#1063305)
* Mon Jul 10 2017 jengelh@inai.de
- Replace vision statement in %%description with feature list.
  Fix RPM groups.
- Drop --with-pic which is only useful for static libs.
* Thu Jun 22 2017 mpluskal@suse.com
- Rename package
* Mon Jun 19 2017 crrodriguez@opensuse.org
- apr 1.6.2
  * apr_allocator: Provide apr_allocator_align()
  * apr_file_io: Add apr_file_pipe_create_pools()
  * Add APR_SO_FREEBIND option for apr_socket_opt_set.
  * apr_skiplist: Add apr_skiplist_addne*()
  * Added Unix domain socket support.
  * See http://www.apache.org/dist/apr/CHANGES-APR-1.6 for
    a full list of changes.
- Drop patches from upstream:
  * 0017-Merge-r1733694-r1733708-from-trunk.patch
  * 0018-apr_proc_mutex-unix-backport-r1733775-from-trunk-par.patch
* Wed Jun 14 2017 crrodriguez@opensuse.org
- define READDIR_IS_THREAD_SAFE, because it is. Avoid
  using obsolete and potentially dangerous readdir_r.
* Wed May  4 2016 crrodriguez@opensuse.org
- 0017-Merge-r1733694-r1733708-from-trunk.patch and
  0018-apr_proc_mutex-unix-backport-r1733775-from-trunk-par.patch
  Refcount shared mutexes usage to avoid
  destruction while still is use by some processes, this fixes
  apache graceful-restart sometimes leaving processes in
  "Gracefully finishing" state forever.
- apr-proc-mutex-map-anon.patch use MAP_ANON instead of mmap'ing
  /dev/zero.
* Tue Sep 29 2015 mpluskal@suse.com
- Add gpg signature
* Sun May  3 2015 crrodriguez@opensuse.org
- remove baselibs.conf that osc rejects now with message:
  ERROR: 'arch' referenced in baselibs.conf is not being built
  ERROR: 'ppc' referenced in baselibs.conf is not being built
  ERROR: 'package' referenced in baselibs.conf is not being built
  ERROR: 'arch' referenced in baselibs.conf is not being built
  ERROR: 'ppc' referenced in baselibs.conf is not being built
  ERROR: 'package' referenced in baselibs.conf is not being built
* Sun May  3 2015 crrodriguez@opensuse.org
- apr 1.5.2
  * apr_escape: Correctly calculate the size of the returned string in
  apr_escape_path and set the correct return value in case we actually
  escape the string
  * apr_poll(cb): fix error paths returned values and leaks.
  * apr_skiplist: Optimize the number of allocations by reusing pooled or
  malloc()ed nodes for the lifetime of the skiplist.
  * apr_skiplist: Fix possible multiple-free() on the same value in
  apr_skiplist_remove_all()
  (obsoletes 0007-backport-r1604596-1604598-from-trunk.patch)
  * apr_global_mutex/apr_proc_mutex: Resolve failures with the
  POSIX sem implementation in environments which receive signals.
  (obsoletes 0009-Merge-r1610854-from-trunk.patch)
  * drop already included or no longer needed patches:
    0004-Backport-r1593600-from-1.6.patch
    0005-Backport-r1593612-from-1.6.patch
    0007-backport-r1604596-1604598-from-trunk.patch
    0009-Merge-r1610854-from-trunk.patch
    string-compare.diff
* Sun Mar  8 2015 crrodriguez@opensuse.org
- No longer use --enable-allocator-uses-mmap but the default
  which is using malloc, this feature exists to reduce
  fragmentation but this is currently at the expense of:
  * Loosing all malloc sanity checks.
  * mmap and munmap are expensive operations when using
    at lot of threads (like in apache worker,event)
  * It will waste memory, even more on archs that have big
    page sizes.
- If there are fragmentation or performance problems in glibc
  malloc, the library has to be fixed instead.
* Sat Mar  7 2015 crrodriguez@opensuse.org
- apr-use-getrandom.patch: Update, if getrandom blocks, fallback
  to the old codepath, restoring old always non-blocking behaviour
  in practice it blocks only at boottime when the entropy pool
  has not been fully initialized, this delays the startup
  of apache for example.
  * Use SYS_getrandom constant instead of the "internal"
  __NR_getrandom
* Sun Oct 19 2014 crrodriguez@opensuse.org
- apr-use-getrandom.patch Use the new getrandom() system call
  in apr_generate_random_bytes() if the system call number
  is defined and if the call is sucessful, fallback if otherwise.
* Tue Aug 19 2014 crrodriguez@opensuse.org
- 0004-Backport-r1593600-from-1.6.patch memory leak apr_pvsprintf()
- 0005-Backport-r1593612-from-1.6.patch Missing error codes in apr_error_string()
- 0007-backport-r1604596-1604598-from-trunk.patch memory corruption in apr_skiplist
- 0009-Merge-r1610854-from-trunk.patch posix semaphore must handle EINTR.
* Mon Jun 23 2014 tchvatal@suse.com
- Single thread for tests.
* Mon Jun 23 2014 tchvatal@suse.com
- Move plain .so file from devel package to fix tomcat intercation.
  bnc#881700
* Fri Jun 20 2014 tchvatal@suse.com
- Remove sparc mentions from baselibs
* Fri Jun 20 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove support for sle9 and friends.
- Fix date and time usage to avoid the completely needless rebuilds
- Run the tests in multiple threads
* Fri Apr 18 2014 crrodriguez@opensuse.org
- apr 1.5.1
  * avoid segfault on apr_os_proc_mutex_get() with cross-
  process pthread mutexes
  * Fix POSIX shared memory (shm_open) use for named shared memory.
  (reenabled in package as well)
* Fri Apr 18 2014 crrodriguez@opensuse.org
- remove apr-1.3.0-testshm-apr_shm_remove.patch, no longer needed
* Thu Nov 21 2013 crrodriguez@opensuse.org
- Update to version 1.5.0. required for upcoming apache 2.4.x
  * Add apr_sockaddr_is_wildcard()
  * Add the apr_escape interface.
  * Add apr_skiplist family.
  * Add the apr_table_getm() call
  * Add apr_hash_this_key(), apr_hash_this_key_len(), and
  apr_hash_this_val()
  * many other changes irrelevant to *nix.
* Tue Sep 24 2013 dmueller@suse.com
- correct condition for avoiding make check is qemu_user_build,
  not armv7l
* Wed Aug 28 2013 crrodriguez@opensuse.org
- Use compiler symbol visibility
* Mon Jul 22 2013 crrodriguez@opensuse.org
- Update to apr 1.4.8
  * Fix amd64 assembler version of apr_atomic_xchgptr()
  * many other bugfixes, see https://www.apache.org/dist/apr/CHANGES-APR-1.4
* Tue Jul 16 2013 mls@suse.de
- get rid of --parents in doc section
* Mon Oct 15 2012 coolo@suse.com
- buildrequire explicitly netcfg for the test suite
* Fri Aug 17 2012 crrodriguez@opensuse.org
- Merge some build improvements/fixes from Fedora
* Sat Feb 18 2012 poeml@cmdline.net
- updated to 1.4.6
  * ) Flush write buffer before truncate call on a file.
  * ) Security: oCERT-2011-003
    Randomise hashes by providing a seed.
  * ) apr_random: Prevent segfault if pool used to initialize apr_random is
    destroyed before forking.
  * ) testrand: Improve child randomness test case.
  * ) apr_proc_fork, apr_random_after_fork: disambiguate what happens to the
    proc structure passed in, and ensure that the pid is set correctly in
    a newly created child; note that merely mixing a PID into the random
    seed of a new child doesn't markedly increase entropy.
  * ) apr_file_open: Avoid fcntl() calls if support for O_CLOEXEC works.
    PR 48557.
  * ) apr_dir_make_recursive: Fix race condition that could lead to EEXIST
    being returned. PR 51254.
  * ) configure: Fix APR_RESTORE_THE_ENVIRONMENT if the original variable was
    a single space. PR 50334.
  * ) apr_proc_create: Don't close any of the new stdin/stdout/stderr in the
    child if it already has the correct FD. PR 51995.
  * ) Fix flag character '#' in combination with format character 'x' in
    apr snprintf implementations.
  * ) Improve platform detection by updating config.guess and config.sub.
  * ) Add libtool2 files to extraclean make target.
  * ) Don't overwrite our config.guess and config.sub
    when running buildconf.
  * ) Silence autoconf 2.68 warnings.
* Tue Jan 24 2012 cfarrell@suse.com
- license update: Apache-2.0
  Fix the license to a single SPDX compatible string
* Fri Jan 20 2012 draht@suse.de
- add Group tag to subpackages
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Sun Aug  7 2011 crrodriguez@opensuse.org
- Fix broken linux 3 version test in configure,make the configure
  script assume linux 2.6.0
* Sat Jul 16 2011 crrodriguez@opensuse.org
- remove -fno-strict-aliasing and LDAP_DEPRECATED from CFLAGS
  no longer needed.
* Thu May 26 2011 crrodriguez@opensuse.org
- Update to APR 1.4.5
  * Security: CVE-2011-1928
  apr_fnmatch(): Fix high CPU loop.  [William Rowe]
  * Fix top_builddir in installed apr_rules.mk.  [Bojan Smojver]
* Fri May 20 2011 crrodriguez@opensuse.org
- Update to APR 1.4.4
  * Security: CVE-2011-0419
  * Fix address handling when accepting an AF_INET socket from a socket
  bound as AF_INET6.
  * Add configure option --enable-allocator-uses-mmap to reduce memory
  fragmentation.
  * Avoid a redundant fcntl() call in apr_file_open() where O_CLOEXEC
  is supported.
* Mon Sep  6 2010 poeml@cmdline.net
- fix build on CentOS5 (see below)
* Mon Sep  6 2010 poeml@cmdline.net
- fix build on SLE10
  - don't run testatomic.c testcase, which fails only in the OBS, as it seems.
    Run manually, it works. Must be either Xen- or ulimit-related. (It doesn't
    seem to be possible to increase ulimit -v in the OBS, unfortunately.)
  - don't run autoconf
- fix build on SLES9
  - remove build dep on non-existing pkg-config
  - don't run autoconf
* Wed Jul 28 2010 poeml@cmdline.net
- Update to 1.4.2:
  Changes for APR 1.4.2
  * ) Undo a crash-bug introduced in 1.3.9 affecting some applications of
    the apr hash and table structures, reported to affect Subversion
    by Bert Huijben <bert qqmail.nl>.  [Graham Leggett]
  Changes for APR 1.4.1
  * ) Win32: Properly handle the ERROR_DIRECTORY system error code.
    [Brane Čibej]
  Changes for APR 1.4.0
  * ) Add apr_global_mutex_lockfile() for retrieving the file, if any,
    associated with the mutex.  Add apr_global_mutex_name() for retrieving
    the name of the lock mechanism used by the underlying proc mutex.
    [Jeff Trawick]
  * ) Add apr_socket_atreadeof to determine whether the receive part of the
    socket has been closed by the peer.
    [Ruediger Pluem, Mladen Turk, Joe Orton]
  * ) Make apr_pollset and apr_pollcb implementations using providers.
    Added apr_pollset_create_ex and apr_pollcb_create_ex that allows
    choosing non-default providers.
    [Mladen Turk]
  * ) apr_temp_dir_get() now checks the TMPDIR environment variable first,
    instead of third.  [Jim Jagielski]
  * ) Add apr_file_sync() and apr_file_datasync() calls.  [Bojan Smojver]
  * ) apr_pollset_wakeup() on Windows: Fix core caused by closing the
    file_socket_pipe with standard file_close.
    [Arsen Chaloyan, Mladen Turk]
  * ) Introduce apr_hash_do() for iterating over a hash table.  [Mladen Turk]
  * ) Make sure WIN32 behaves the same as posix for file-backed shared memory
    by removing the file on cleanup/remove.  [Mladen Turk]
  * ) Introduce apr_pollset_wakeup() for interrupting the blocking
    apr_pollset_poll() call.  [Mladen Turk]
  * ) Add apr_file_link() function.  PR 44841.  [Mark Heily <mark heily.com>]
  Changes for APR 1.3.12
  * ) Fix detection of some Linux variants when configure is built with
    recent GNU tools.  [Eric Covener]
  Changes for APR 1.3.11
  * ) Fix bad autoconf version number in messages from buildcheck.sh
    (called from buildconf).  [Jeff Trawick]
  Changes for APR 1.3.10
  * ) Avoid a redundant fcntl() call in apr_file_open() where O_CLOEXEC
    is supported.  PR 46297.  [Joe Orton]
  * ) Solaris 10 and later: Change the default cross-mutex mechanism from
    fcntl to pthread to resolve EDEADLK failures with some multi-threaded,
    multi-process applications (e.g., httpd's worker MPM with certain
    plug-in modules).  [Jeff Trawick]
  * ) Solaris pollcb support: Fix a hang in apr_pollcb_poll().
    [Jeff Trawick]
  * ) Solaris pollset support: Fix a 1.3.9 regression in apr_pollset_poll()
    which could result in a crash when the call was interrupted by a
    signal.  PR 48030.  [Jeff Trawick]
  * ) Solaris pollset support: Fix a 1.3.9 regression in apr_pollset_poll()
    which resulted in invalid return codes from the APR function.  A work-
    around was needed for bad return codes from 32-bit port_getn() on
    Solaris 10 x86.  PR 48029.  [Jeff Trawick]
  Changes for APR 1.3.9
  * ) Posix semaphores can now be named and used as named semaphores.
    [Jim Jagielski]
  * ) Better handling of APR_OFF_T_FMT for Darwin 10 depending on -arch
    setting of compiler. [Jim Jagielski]
  * ) Add comments describing the thread-safety properties of apr_pool_t.
    [Neil Conway nrc cs.berkeley.edu]
  * ) Pass default environment to testsock, testshm and testproc children, so
    that tests run when APR is compiled with Intel C Compiler.
    [Bojan Smojver]
  * ) Fix error handling in the Solaris pollset support (Event Port backend).
    PR 47645.  [Jeff Trawick]
  * ) Add the remainder of this fix from trunk:
    Fix Solaris poll failure.  PR 43000
    [Henry Jen <henryjen ztune.net>]
* Sat Jun 12 2010 bg@novell.com
- remove test testatomic on hppa to fix build
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- package baselibs for SPARC
* Mon Aug 10 2009 poeml@suse.de
- update to 1.3.8
  * ) SECURITY: CVE-2009-2412 (cve.mitre.org)
    Fix overflow in pools and rmm, where size alignment was taking place.
  * ) Make sure that "make check" is used in the RPM spec file, consistent
    with apr-util.
  * ) Pass default environment to testflock, testoc and testpipe children,
    so that tests run when APR is compiled with Intel C Compiler.
* Wed Jul 29 2009 poeml@suse.de
- obsolete patch apr-1.2.8-pool-cleanups.patch removed.
  This patch was applied only when build_with_memory_pool_debug was
  defined during the build, which is true for the Apache:APR_Pool_Debug project,
  but it was disabled even there.
  It was not clear whether the patch was really useful, I seemed to
  have more success testing with the pool debug builds with this
  patch. But that was two years ago and we don't seem to miss it.
* Mon Jul 27 2009 poeml@suse.de
- update to 1.3.7
  * ) More elaborate detection for dup3(), accept4() and epoll_create1().
* Wed Jul  8 2009 poeml@suse.de
- update to 1.3.6
  * ) On Linux/hppa flock() returns EAGAIN instead of EWOULDBLOCK. This
    causes proc mutex failures.
  * ) Set CLOEXEC flags where appropriate. Either use new O_CLOEXEC flag and
    associated functions, such as dup3(), accept4(), epoll_create1() etc.,
    or simply set CLOEXEC flag using fcntl().  PR 46425.
* Mon Jun  8 2009 poeml@suse.de
- update to 1.3.5
  * ) Dropped kqueue and apr_poll detection from Mac OS/X 10.5/Darwin 9
    due to various reported problems.
  * ) apr_strerror() on OS/2: Fix problem with calculating buffer size.
  * ) Prefer glibtool1/glibtoolize1.
  * ) Fix buildconf with libtool 2.2.
  * ) Fix a bug with the APR_DELONCLOSE flag. Child processes were (also)
    unlinking the file.
  * ) Fix compilation error on systems that do not have IPV6.
  * ) apr_socket_sendfile() on Solaris: Fix handling of files truncated
    after the sender determines the length.  (This fixes a busy loop in
    httpd when a file being served is truncated.)
  * ) Fix documentation for apr_temp_dir_get().
  * ) Add AC_MSG_RESULT after AC_MSG_CHECKING.
  * ) Reset errno to zero in apr_strtoi64 to prevent returning an errno not
    equal zero in cases where the operation worked fine. [Ruediger Pluem]
  * ) Win32: Do not error out on apr_pollset_poll() when there are no sockets.
  * ) Fix apr_tokenize_to_argv parsing.
* Mon Nov 17 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Fri Nov 14 2008 poeml@suse.de
- simplify the usage of the sles_version macro
* Thu Oct 30 2008 skh@suse.de
- obsolete old -XXbit packages (bnc#437293) (olh@suse.de)
* Tue Aug 19 2008 poeml@suse.de
- update to 1.3.3 final
  (updating to the release tarball, which has all the patches.)
* Sat Aug  9 2008 poeml@suse.de
- add apr-1.3.2-r684091.patch
  Backport r683771 from the trunk.
  Fix APR_PID_T_FMT detection on Solaris.
- rename apr-1.3.3-patch to apr-1.3.3.patch
* Thu Aug  7 2008 poeml@suse.de
- add post-1.3.2 patches (backports from trunk committed to the
  1.3.x branch)
  * ) Rename apr_pool_create_core to apr_pool_create_unmanaged and
    deprecate the old API name. It better reflects the scope and usage
    of this function. [Mladen Turk]
  * ) Use proper return code for fcntl-based apr_proc_mutex_trylock()
    on platforms that return EACCES instead of EAGAIN when the lock
    is already held (AIX, HP-UX).  [Eric Covener]
* Thu Aug  7 2008 poeml@suse.de
- update to 1.3.2. Changes:
  * ) Fix getservbyname_r() detection.  [Ruediger Pluem]
  * ) Fix win32 apr.hw to pick up XP/2003 TCP/IP multicast constants and
    revert to IPV6 disabled-by-default (a change present only in 1.3.0).
    [William Rowe]
  * ) Fix autoconf cached detection of atomic builtins.  [Jim Jagielski]
  * ) Use thread safe versions of getservbyname().  [Bojan Smojver]
  * ) Use thread safe getpass_r on Netware.  [Guenter Knauf]
* Thu Jul 17 2008 poeml@suse.de
- skip testatomic testcase on sles9-x86_64 for now
* Thu Jul 17 2008 poeml@suse.de
- workaround for ugly bug [bnc#400488]
  Xen kernel on sles9 x86_64 is set up to behave different than all
  other kernels
* Sun Jun 15 2008 poeml@suse.de
- update to 1.3.0. Changes, with non-Linux relevant portions
  omitted (see http://www.apache.org/dist/apr/CHANGES-APR-1.3 for
  complete list):
  * ) apr_getservbyname(): Use proper method for converting port
    to host byte order.  PR 44903.
    [Chris Taylor <ctaylor wadeford.plus.com>]
  * ) Use /dev/urandom in preference to /dev/random as entropy source
    for apr_generate_random_bytes.  PR 44881.  [Bojan Smojver]
  * ) Introduce apr_pool_pre_cleanup_register() for registering
    a cleanup that is called before any subpool is destroyed
    within apr_pool_clear or apr_pool_destroy.
    This allows to register a cleanup that will notify subpools
    about its inevitable destruction.
    [Mladen Turk]
  * ) Introduce apr_pool_create_core_ex() for creation of standalone
    pools without parent. This function should be used for short
    living pools, usually ones that are created and destroyed
    either in a loop or inside function call. Since the pools
    created with this function doesn't have a parent they must
    be explicitly destroyed when done.
    [Mladen Turk]
  * ) Fix return value when apr_pollset_poll interrupted.
    PR 42580 [Basant Kumar Kukreja <basant.kukreja sun.com>]
  * ) Fix the make test target in the spec file. [Graham Leggett]
  * ) Introduce apr_file_pipe_create_ex() to portably permit one pipe
    end or another to be entirely blocking for non-APR applications
    (e.g. stdio streams) and the other (or both ends) non blocking,
    with a timeout of 0 by default.
    [William Rowe]
  * ) Introduce APR_NO_FILE as an option to apr_procattr_io_set() for any
    of the three stdio streams to cause the corresponding streams to be
    closed to the child process.  This becomes effective in 1.3.0 across
    platforms (equivilant to APR_NO_PIPE in 1.2.x except on Win32.)
    [William Rowe]
  * ) Add table cloning (deep copy) convenience function.
    [Davi Arnaut]
  * ) Stop invoking the testshm* helpers upon 'make test' invocation.
    [Kurt Miller <kurt intricatesoftware.com>]
  * ) Register a cleanup only if APR_FILE_NOCLEANUP was not flagged in
    apr_file_mktemp. [Brian J. France <list firehawksystems.com>]
  * ) Discard file buffers when running cleanups for exec.
    PR 41119.  [Davi Arnaut <davi haxent.com.br>, Bojan Smojver]
  * ) Improve thread safety of assorted file_io functions.
    PR 42400.  [Davi Arnaut <davi haxent.com.br>]
  * ) Add the apr_pollcb API as an alternative more efficient method
    of polling sockets, compared to apr_pollset. [Paul Querna]
  * ) Fix possible crash in apr_pool_initialize() when built with
    verbose pool debugging.  PR 41063.
    [Peter Steiner <peter.steiner+apache hugwi.ch>]
  * ) Fix --disable-ipv6 build on platforms with getifaddrs().
    PR 39199.  [Joe Orton]
  * ) Portably check for EEXIST in mktemp code.  PR 40818
    [Kenneth Golomb <KGolomb TradeCard.com>]
  * ) Fix apr_socket_recvfrom() to ensure the peer's address is returned
    through the "from" parameter.  [Joe Orton]
  * ) Fix error checking in kqueue, epoll and event port versions of
    apr_pollset_create.  PR 40660, 40661, 40662
    [Larry Cipriani <lvc lucent.com>]
  * ) Add some documentation on the format matched by apr_fnmatch.
    [David Glasser <glasser mit.edu>]
  * ) Add apr_hash_clear.  [Daniel L. Rall <dlr apache.org>]
  * ) Don't try to build apr_app.c on MinGW.
    [Matthias Miller <Blog outofhanwell.com>]
  * ) Fix the timeout converstion in apr_pollset with the KQueue
    backend. [Marco Molteni <mmolteni cisco.com>]
  * ) Support MinGW.  [John Vandenberg, Justin Erenkrantz]
  * ) Implement apr_thread_yield on Unix in terms of pthread_yield or
    sched_yield. [Keisuke Nishida <keisuke.nishida gmail.com>]
  * ) Make apr_socket_recvfrom initialize the port field in the from
    sockaddr.  PR 39325 [Anthony Minessale <anthmct yahoo.com>]
  * ) NetBSD: Avoid leaving zombie process when using apr_signal()
    to ignore SIGCHLD.  PR 36750.  [Todd Vierling <tv pobox.com>]
  * ) Implement support for apr_proc_mutex_trylock() on Unix platforms.
    PR 38785.  [Chris Darroch <chrisd pearsoncmg.com>]
  * ) APR_FIND_APR macro now supports customisable detailed checks on
    each installed apr. [Justin Erenkrantz, Colm MacCarthaigh]
  * ) APR_FIND_APR macro no longer checks /usr/local/apache2/
    [Colm MacCarthaigh]
  * ) Add APR_POLLSET_NOCOPY option to apr_pollset API to eliminate
    O(n)-time lookup in apr_pollset_remove() (currently implemented
    only for epoll).  [Brian Pane]
  * ) Add apr_file_buffer_set() and apr_file_buffer_size_get() functions
    to support variable buffer sizes with APR file handles.
    [Colm MacCarthaigh]
  * ) Add apr_file_open_flags_std[err|out|in]() functions.
    [Colm MacCarthaigh]
  * ) stdio: apr_file_open_std[err|out|in]() functions now set the APR_WRITE
    or APR_READ flag as appropriate. [Colm MacCarthaigh]
  * ) multicast: apr_mcast_*() no longer return APR_ENOTIMPL when invoked
    for non-UDP/RAW sockets. The caller is expected to ensure that the
    socket-type is suitable for multicast. [Colm MacCarthaigh]
  * ) Add apr_sockaddr_ip_getbuf() function.  [Joe Orton]
  * ) Fix handling of %%pI in apr_psprintf.  [Joe Orton]
  * ) Provide APR_VERSION_AT_LEAST() macro for applications which
    want to enable features based on a required level of APR.
    [Jeff Trawick]
  * ) jlibtool: Teach to use static libraries with -static.
    [Justin Erenkrantz]
  * ) Fix checks for alloca() support in configure.  PR 13037.
    [Noah Misch <noah cs.caltech.edu>]
  * ) Add %%pm support to apr_snprintf() for printing the error string
    corresponding to an apr_status_t value.  [Joe Orton]
  * ) Add APR_ARRAY_IDX() and APR_ARRAY_PUSH() convenience macros to
    apr_tables.h.  [Garrett Rooney]
- fix testshm testcase
- remove manual addition of -g, since the OBS takes care of it now.
* Mon Jun  9 2008 poeml@suse.de
- build service supports the debuginfo flag in metadata now; remove
  debug_package macro from the specfile therefore.
* Tue Apr 15 2008 schwab@suse.de
- Don't use autoreconf.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Nov 26 2007 poeml@suse.de
- update to 1.2.12 (only changes relevant on Linux listed here):
  * ) Numerous fixes to the test/ framework, including better handling of
    long size_t comparisons and more consistent Makefile.(in|win) setup
    for authoring new tests.  [William Rowe]
  * ) Fix --disable-ipv6 build on platforms with getifaddrs().
    PR 39199.  [Joe Orton]
  * ) Define apr_ino_t in such a way that it doesn't change definition
    based on the library consumer's -D'efines to the filesystem.
    [Lucian Adrian Grijincu <lucian.grijincu gmail.com>]
  * ) Fill in apr_fileinfo_t member st_csize on Netware and Unix (PR 41678),
    and refine the file times down to apr_time_t resolution if supported
    by a st_atimensec or st_atim.tv_nsec value by the OS.  Additional
    msec implementations are possible if exposed through autoconf.
    [William Rowe, Nicklas Edmundsson <nikke acc.umu.se>]
  * ) Fix apr_socket_recvfrom() to ensure the peer's port and address
    is returned through the "from" parameter on Unix and Win32.
    [Joe Orton, William Rowe]
* Wed Sep 12 2007 poeml@suse.de
- fix missing endif in build section, fixing build on Mandriva
  (went unnoticed on openSUSE)
- use debug_package macro only on suse, because it breaks the build
  on Mandriva
* Wed Sep 12 2007 poeml@suse.de
- don't run autoreconf -fi on build platforms older than 10.3. The
  'i' in that replaces config.guess, config.sub, ltmain.sh (dated
  2007) with versions from, say, 2005. This will lead to a
  miscompile on SLE10 for instance (segfault in apr_initialize())
- don't apply the cleanup apr-1.2.8-pool-cleanups.patch when built
  with build_with_memory_pool_debug for now
* Mon Sep 10 2007 poeml@suse.de
- update to 1.2.11:
  * ) Win32 apr_file_read; Correctly handle completion-based read-to-EOF.
    [Steven Naim <steven.naim googlemail.com>]
  * ) Fixed Win32 regression of stdout inheritance in apr_proc_create.
    [William Rowe]
  * ) Solve winNT inherited pipe leaks by mutexing apr_proc_create calls,
    on WinNT (not WinCE, nor 9x) so that we toggle the inherited state
    of the stdin/out/err pipes.  All other file handles are treated as
    not-inherited until apr_file_dup2'ed a std handle of this process,
    or while they are used by apr_proc_create.  [William Rowe]
  * ) Define the Mac OS/X filesystem_encoding as utf-8 (in previous
    releases the interpretation would vary).  [Erik Huelsmann
    <ehuels gmail.com>]
  * ) Fix day of year (tm_day) calculation for July. The bug only affects
    Windows builds.  PR 42953.  [Davi Arnaut]
  * ) Fix LFS detection when building over NFS. The mode must be
    specified when O_CREAT is in the flags to open().
    PR 42821.  [Rainer Jung <rainer.jung kippdata.de>]
  * ) Avoid overwriting the hash_mutex table for applications that
    incorrectly calls apr_atomic_init().  PR 42760.  [Davi Arnaut]
  * ) Allow IPv6 connectivity test to fail, avoiding a potentially fatal
    error.  [Davi Arnaut]
  * ) The MinGW Windows headers effectively redefines WINADVAPI from
    __stdcall to empty which results in a link failure when wincrypt.h
    is placed after an include to apr_private.h.
    PR 42293.  [Curt Arnold]
  * ) Define SEM_FAILED if it isn't already defined, as the proc mutex
    code already does it. Also search for the sem_open function in
    the realtime library. (This fixes HP-UX sem_open detection).
    [Davi Arnaut]
  * ) Define the _HPUX_SOURCE feature test macro to obtain maximum
    functionality. Fixes broken sendfile with LFS support on HP-UX.
    PR 42261.  [Davi Arnaut]
* Tue Aug 21 2007 crrodriguez@suse.de
- first attempt to remove static libraries and libtool crap.
* Mon Aug 20 2007 poeml@suse.de
- on SLES9, use 'autoheader; autoconf' to configure, as before,
  instead of autoreconf -fi, which won't work
* Sun Aug 12 2007 crrodriguez@suse.de
- apr 1.2.9
  * ) Stop invoking the testshm* helpers upon 'make test' invocation.
  * ) Register a cleanup only if APR_FILE_NOCLEANUP was not flagged in
    apr_file_mktemp.
  * ) Discard file buffers when running cleanups for exec.
    PR 41119.
  * ) If apr_proc_create() fails to exec in the fork()ed child, call
    _exit() not exit() to avoid running atexit()-registered functions
    in the child.
  * ) Improve thread safety of assorted file_io functions.
  * ) Fix file pointer position calculation in apr_file_writev() on
    buffered file.
  * ) Fix formatting of unsigned integers larger than 2^63 in the
    vformatter/apr_*printf.
  * ) Fix possible EFAULT failures in apr_socket_sendfile() on 32-bit
    Solaris with LFS enabled
  * ) Fix deadlock in apr_file_gets() for a file opened with both the
    APR_BUFFERED and APR_XTHREAD flags.
- run make ceck in the rpm check section
- add missing glibc-devel dependency to -devel package
* Wed Jul 18 2007 poeml@suse.de
- if the rpm macro build_with_memory_pool_debug is defined, build
  with --enable-pool-debug=verbose-alloc. (This is the case in the
  Apache-Pool-Debug buildservice project.)
- add apr-1.2.8-pool-cleanups.patch: don't run cleanup handlers
  _after_ destroying subpools
- add debug_package macro in buildservice (will soon be obsolete)
* Wed May  2 2007 dmueller@suse.de
- Fix comparison with string literal
* Mon Dec 11 2006 poeml@suse.de
- update to 1.2.8
  * ) Correctly retrieve 'empty' environment values with apr_env_get
    on Win32 (e.g. "VAR="), and added validation to testall suite.
  * ) APR_FIND_APR macro no longer checks /usr/local/apache2/.
  * ) Portably check for EEXIST in mktemp code.  PR 40818
  * ) Fix apr_snprintf/apr_vsnprintf return value to not count the
    NUL terminator in the overflow case.  PR 39996.
  * ) Fix detection of pthread cross-process robust mutexes.
  * ) NetBSD: Avoid leaving zombie process when using apr_signal()
    to ignore SIGCHLD.
  * ) Fix apr_socket_sendv() for platforms without writev.
  * ) Avoid issues using >2Gb of data per call with sendfile() on
    64-bit Linux platforms.
* Fri Oct 27 2006 poeml@suse.de
- replace wrong configure switch --with-includedir with the correct
  one: --includedir. This fixes installation of the header files to
  /usr/include/apr-1 instead of /usr/include. [#164770]
* Thu Jun 22 2006 schwab@suse.de
- Don't depend on configure args being preserved.
* Wed May 24 2006 poeml@suse.de
- update to 1.2.7
  * fixes for netware and win32
- update to 1.2.6
  * bugfixes for libuuid, mutex, kqueue, ...
- use %%suse_version to build doxygen documentation only on SUSE
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 poeml@suse.de
- don't use pthread_mutexattr_setrobust_np() unless
  pthread_mutexattr_setprotocol() is available as well (the former
  is in glibc since 2005-12-26, but the latter not)
* Wed Oct 12 2005 poeml@suse.de
- update to 1.2.2
* Thu Sep 29 2005 poeml@suse.de
- update to 1.2.1
- add -fno-strict-aliasing to CFLAGS
- add -DLDAP_DEPRECATED to CFLAGS
* Fri Apr  8 2005 uli@suse.de
- disabled test suite for ARM (may hang QEMU)
* Thu Mar 24 2005 poeml@suse.de
- update to 1.1.1
* Fri Feb 25 2005 poeml@suse.de
- package created (1.1.0)
